@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,19 +27,18 @@
 #include "kpimtextedit/plaintexteditor.h"
 #include <KSyntaxHighlighting/Repository>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextEditorCompleter;
 class InsertHtmlEditor : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
 public:
-    explicit InsertHtmlEditor(QWidget *parent = Q_NULLPTR);
+    explicit InsertHtmlEditor(QWidget *parent = nullptr);
     ~InsertHtmlEditor();
 protected:
-    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *e) override;
 private:
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
+    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
     KSyntaxHighlighting::Repository mRepo;
 };
 }
