@@ -31,12 +31,9 @@
 #include <QSpinBox>
 #include <QVBoxLayout>
 #include <QMimeDatabase>
-#include <QDebug>
 
-namespace KPIMTextEdit
-{
-
-static inline QString resolveAlias(const QString& name)
+namespace KPIMTextEdit {
+static inline QString resolveAlias(const QString &name)
 {
     QMimeDatabase db;
     const QString str = db.mimeTypeForName(name).name();
@@ -47,7 +44,8 @@ class InsertImageWidgetPrivate
 {
 public:
     InsertImageWidgetPrivate(InsertImageWidget *qq)
-        : imageRatio(-1), q(qq)
+        : imageRatio(-1)
+        , q(qq)
     {
         QVBoxLayout *lay = new QVBoxLayout(q);
         lay->setMargin(0);
@@ -67,8 +65,8 @@ public:
         imageUrlRequester->setMimeTypeFilters(lstMimeTypes);
         imageUrlRequester->setWindowTitle(i18n("Add Image"));
         imageUrlRequester->setMode(KFile::File);
-        q->connect(imageUrlRequester->lineEdit(), SIGNAL(textChanged(QString)),
-                   q, SLOT(_k_slotUrlChanged(QString)));
+        q->connect(imageUrlRequester->lineEdit(), &KLineEdit::textChanged,
+                   q, [this](const QString &str) { _k_slotUrlChanged(str);});
 
         hbox->addWidget(lab);
         hbox->addWidget(imageUrlRequester);
@@ -76,8 +74,8 @@ public:
         lay->addLayout(hbox);
 
         keepOriginalSize = new QCheckBox(i18n("Keep Original Size"));
-        q->connect(keepOriginalSize, SIGNAL(clicked(bool)),
-                   q, SLOT(_k_slotKeepOriginalSizeClicked(bool)));
+        q->connect(keepOriginalSize, &QCheckBox::clicked,
+                   q, [this](bool b) { _k_slotKeepOriginalSizeClicked(b);});
         keepOriginalSize->setChecked(true);
         lay->addWidget(keepOriginalSize);
 
@@ -94,8 +92,8 @@ public:
         width->setEnabled(false);
         width->setSuffix(i18n(" px"));
         lab->setBuddy(width);
-        q->connect(width, SIGNAL(valueChanged(int)),
-                   q, SLOT(_k_slotImageWidthChanged(int)));
+        q->connect(width, QOverload<int>::of(&QSpinBox::valueChanged),
+                   q, [this](int val) { _k_slotImageWidthChanged(val);});
         hbox->addWidget(lab);
         hbox->addWidget(width);
         lay->addLayout(hbox);
@@ -108,8 +106,8 @@ public:
         height->setEnabled(false);
         height->setSuffix(i18n(" px"));
         lab->setBuddy(height);
-        q->connect(height, SIGNAL(valueChanged(int)),
-                   q, SLOT(_k_slotImageHeightChanged(int)));
+        q->connect(height, QOverload<int>::of(&QSpinBox::valueChanged),
+                   q, [this](int val) { _k_slotImageHeightChanged(val);});
         hbox->addWidget(lab);
         hbox->addWidget(height);
         lay->addLayout(hbox);
@@ -133,13 +131,13 @@ public:
     void _k_slotImageHeightChanged(int);
 
     qreal imageRatio;
-    QCheckBox *keepOriginalSize;
-    QCheckBox *keepImageRatio;
-    QSpinBox *width;
-    QSpinBox *height;
-    KUrlRequester *imageUrlRequester;
-    QLabel *preview;
-    InsertImageWidget *q;
+    QCheckBox *keepOriginalSize = nullptr;
+    QCheckBox *keepImageRatio = nullptr;
+    QSpinBox *width = nullptr;
+    QSpinBox *height = nullptr;
+    KUrlRequester *imageUrlRequester = nullptr;
+    QLabel *preview = nullptr;
+    InsertImageWidget *q = nullptr;
 };
 
 void InsertImageWidgetPrivate::_k_slotKeepOriginalSizeClicked(bool checked)
@@ -164,7 +162,7 @@ void InsertImageWidgetPrivate::_k_slotUrlChanged(const QString &text)
         preview->clear();
         imageRatio = -1;
     }
-    q->enableButtonOk(!text.trimmed().isEmpty());
+    Q_EMIT q->enableButtonOk(!text.trimmed().isEmpty());
 }
 
 void InsertImageWidgetPrivate::_k_slotImageWidthChanged(int value)
@@ -190,7 +188,8 @@ void InsertImageWidgetPrivate::_k_slotImageHeightChanged(int value)
 }
 
 InsertImageWidget::InsertImageWidget(QWidget *parent)
-    : QWidget(parent), d(new InsertImageWidgetPrivate(this))
+    : QWidget(parent)
+    , d(new InsertImageWidgetPrivate(this))
 {
 }
 
@@ -233,7 +232,6 @@ bool InsertImageWidget::keepOriginalSize() const
 {
     return d->keepOriginalSize->isChecked();
 }
-
 }
 
 #include "moc_insertimagewidget.cpp"
