@@ -23,7 +23,6 @@
 #include <KLocalizedString>
 #include <KIconTheme>
 #include <KStandardGuiItem>
-#include <KMessageBox>
 #include <KStandardAction>
 #include <KCursor>
 #include <QIcon>
@@ -36,7 +35,6 @@
 #include "texttospeech/texttospeech.h"
 
 #include <QMenu>
-#include <QDBusInterface>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QTextDocumentFragment>
@@ -82,16 +80,16 @@ public:
 
     QStringList ignoreSpellCheckingWords;
     PlainTextEditor *q;
-    KPIMTextEdit::TextMessageIndicator *mTextIndicator;
-    KIO::KUriFilterSearchProviderActions *webshortcutMenuManager;
-    Sonnet::SpellCheckDecorator *richTextDecorator;
-    Sonnet::Speller *speller;
+    KPIMTextEdit::TextMessageIndicator *mTextIndicator = nullptr;
+    KIO::KUriFilterSearchProviderActions *webshortcutMenuManager = nullptr;
+    Sonnet::SpellCheckDecorator *richTextDecorator = nullptr;
+    Sonnet::Speller *speller = nullptr;
 
     QString spellCheckingConfigFileName;
     QString spellCheckingLanguage;
     QTextDocumentFragment originalDoc;
     PlainTextEditor::SupportFeatures supportFeatures;
-    int mInitialFontSize;
+    int mInitialFontSize = 0;
     bool customPalette;
     bool activateLanguageMenu;
     bool checkSpellingEnabled;
@@ -370,8 +368,8 @@ void PlainTextEditor::slotCheckSpelling()
     connect(spellDialog, &Sonnet::Dialog::replace, this, &PlainTextEditor::slotSpellCheckerCorrected);
     connect(spellDialog, &Sonnet::Dialog::misspelling, this, &PlainTextEditor::slotSpellCheckerMisspelling);
     connect(spellDialog, &Sonnet::Dialog::autoCorrect, this, &PlainTextEditor::slotSpellCheckerAutoCorrect);
-    connect(spellDialog, SIGNAL(done(QString)),
-            this, SLOT(slotSpellCheckerFinished()));
+    connect(spellDialog, QOverload<const QString &>::of(&Sonnet::Dialog::done),
+            this, &PlainTextEditor::slotSpellCheckerFinished);
 
     connect(spellDialog, &Sonnet::Dialog::cancel, this, &PlainTextEditor::slotSpellCheckerCanceled);
     connect(spellDialog, &Sonnet::Dialog::spellCheckStatus, this, &PlainTextEditor::spellCheckStatus);
