@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,8 +25,7 @@
 #include <QTextDocument>
 
 class QTextEdit;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextEditFindBarPrivate;
 class KPIMTEXTEDIT_EXPORT RichTextEditFindBar : public TextEditFindBarBase
 {
@@ -36,22 +35,21 @@ public:
     ~RichTextEditFindBar();
 
 protected:
-    bool viewIsReadOnly() const Q_DECL_OVERRIDE;
-    bool documentIsEmpty() const Q_DECL_OVERRIDE;
-    bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) Q_DECL_OVERRIDE;
-    void autoSearchMoveCursor() Q_DECL_OVERRIDE;
+    bool viewIsReadOnly() const override;
+    bool documentIsEmpty() const override;
+    bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) override;
+    void autoSearchMoveCursor() override;
 
 public Q_SLOTS:
-    void slotSearchText(bool backward = false, bool isAutoSearch = true) Q_DECL_OVERRIDE;
+    void slotSearchText(bool backward = false, bool isAutoSearch = true) override;
 
 private Q_SLOTS:
-    void slotReplaceText() Q_DECL_OVERRIDE;
-    void slotReplaceAllText() Q_DECL_OVERRIDE;
+    void slotReplaceText() override;
+    void slotReplaceAllText() override;
 
 private:
     RichTextEditFindBarPrivate *const d;
 };
-
 }
 
 #endif // RICHTEXTEDITFINDBAR_H
