@@ -42,7 +42,6 @@
 
 #include <QMenu>
 #include <QContextMenuEvent>
-#include <QDBusInterface>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QTextCursor>
@@ -85,14 +84,14 @@ public:
     }
 
     QStringList ignoreSpellCheckingWords;
-    RichTextEditor *q;
-    KPIMTextEdit::TextMessageIndicator *textIndicator;
+    RichTextEditor *q = nullptr;
+    KPIMTextEdit::TextMessageIndicator *textIndicator = nullptr;
     QString spellCheckingConfigFileName;
     QString spellCheckingLanguage;
     QTextDocumentFragment originalDoc;
-    Sonnet::SpellCheckDecorator *richTextDecorator;
-    Sonnet::Speller *speller;
-    KIO::KUriFilterSearchProviderActions *webshortcutMenuManager;
+    Sonnet::SpellCheckDecorator *richTextDecorator = nullptr;
+    Sonnet::Speller *speller = nullptr;
+    KIO::KUriFilterSearchProviderActions *webshortcutMenuManager = nullptr;
     RichTextEditor::SupportFeatures supportFeatures;
     int mInitialFontSize;
     bool customPalette;
@@ -447,7 +446,9 @@ void RichTextEditor::checkSpelling(bool force)
         QPushButton *skipButton = new QPushButton(i18n("Skip"));
         buttonBox->addButton(skipButton, QDialogButtonBox::ActionRole);
         connect(skipButton, &QPushButton::clicked, spellDialog, &Sonnet::Dialog::close);
-        connect(skipButton, &QPushButton::clicked, this, &RichTextEditor::spellCheckingFinished);
+        if (force) {
+            connect(skipButton, &QPushButton::clicked, this, &RichTextEditor::spellCheckingFinished);
+        }
     } else {
         qCWarning(KPIMTEXTEDIT_LOG) << " Impossible to find qdialogbuttonbox";
     }
@@ -457,7 +458,8 @@ void RichTextEditor::checkSpelling(bool force)
     connect(spellDialog, &Sonnet::Dialog::replace, this, &RichTextEditor::slotSpellCheckerCorrected);
     connect(spellDialog, &Sonnet::Dialog::misspelling, this, &RichTextEditor::slotSpellCheckerMisspelling);
     connect(spellDialog, &Sonnet::Dialog::autoCorrect, this, &RichTextEditor::slotSpellCheckerAutoCorrect);
-    connect(spellDialog, SIGNAL(done(QString)), this, SLOT(slotSpellCheckerFinished()));
+    connect(spellDialog, QOverload<const QString &>::of(&Sonnet::Dialog::done),
+            this, &RichTextEditor::slotSpellCheckerFinished);
     connect(spellDialog, &Sonnet::Dialog::cancel, this, &RichTextEditor::slotSpellCheckerCanceled);
     connect(spellDialog, &Sonnet::Dialog::spellCheckStatus, this, &RichTextEditor::spellCheckStatus);
     connect(spellDialog, &Sonnet::Dialog::languageChanged, this, &RichTextEditor::languageChanged);
