@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,27 +24,24 @@
 #include "texttospeechwidget.h"
 #include "abstracttexttospeechinterface.h"
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextToSpeechWidget;
 class TextToSpeechInterfacePrivate;
 class KPIMTEXTEDIT_EXPORT TextToSpeechInterface : public AbstractTextToSpeechInterface
 {
     Q_OBJECT
 public:
-    explicit TextToSpeechInterface(TextToSpeechWidget *textToSpeechWidget, QObject *parent = Q_NULLPTR);
+    explicit TextToSpeechInterface(TextToSpeechWidget *textToSpeechWidget, QObject *parent = nullptr);
     ~TextToSpeechInterface();
 
-    bool isReady() const Q_DECL_OVERRIDE;
-    void say(const QString &text) Q_DECL_OVERRIDE;
-    int volume() const Q_DECL_OVERRIDE;
-    void setVolume(int value) Q_DECL_OVERRIDE;
-    void reloadSettings() Q_DECL_OVERRIDE;
-
-private Q_SLOTS:
-    void stateChanged(KPIMTextEdit::TextToSpeechWidget::State state);
+    bool isReady() const override;
+    void say(const QString &text) override;
+    int volume() const override;
+    void setVolume(int value) override;
+    void reloadSettings() override;
 
 private:
+    void stateChanged(KPIMTextEdit::TextToSpeechWidget::State state);
     TextToSpeechInterfacePrivate *const d;
 };
 }
